@@ -1,6 +1,7 @@
 from datetime import datetime
 from typing import Dict, List, Optional
 from uuid import UUID
+from pydantic import validator
 
 from serenity_types.pricing.derivatives.options.volsurface import (
     InterpolatedVolatilitySurface, VolModel, DiscountingMethod
@@ -172,6 +173,18 @@ class OptionValuationRequest(CamelModel):
     individual overrides or bumps for all inputs as part of each valuation object.
     """
 
+    @validator('yield_curves', always=True)
+    def check_yield_curve_ids_or_yield_curves(cls, yield_curves, values):
+        if values.get('yield_curve_ids') and yield_curves:
+            raise ValueError("Please specify only one of 'yield_curve_ids' or 'yield_curves'")
+        return yield_curves
+
+    @validator('vol_surface', always=True)
+    def check_vol_surface_id_or_vol_surface(cls, vol_surface, values):
+        if values.get('vol_surface_id') and vol_surface:
+            raise ValueError("Please specify only one of 'vol_surface_id' or 'vol_surface'")
+        return vol_surface
+
 
 class OptionValuationResult(CamelModel):
     """
@@ -231,7 +244,7 @@ class OptionValuationResult(CamelModel):
     Delta X qty X contract_size, the delta exposure expressed in qty of underlying.
     """
 
-    delta_ccy: float
+    delta_ccy: Optional[float]
     """
     Delta X value, a.k.a. the partial derivative of position value with respect to spot,
     expressed in base currency
